from tkinter import Menu
import tkinter as tk
class MenuSet(Menu):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.Gui_Show()
    def Gui_Show(self):
        self.add_command(label="导入",command=lambda :self.KeyDeal("Import"))
        self.add_command(label="导出",command=lambda :self.KeyDeal("Export"))
        self.add_command(label="保存",command=lambda :self.KeyDeal("Save"))
    def KeyDeal(self,action:str):
        if action=="Import":
            self.m_CallBackImport()
        elif action=="Export":
            self.m_CallBackExport()
        elif action=="Save":
            self.m_CallBackSave()
    def m_CallBackImport(self):
        print("Import")
    def m_CallBackExport(self):
        print("Export")
    def m_CallBackSave(self):
        print("Save")




from .base_enhance.ListFrame import ListFrame
from .base_enhance.LogFrame import LogFrame
from .base_enhance.RollingLabel import RollingLabel
from .base_enhance.TableFrame import TableFrame
from .base_enhance.TipShow import TipShow
#0.4
#获取最新版本
#pip install git+https://gitee.com/w-8/tktk.git






import tkinter as tk
from tkinter import LabelFrame

class ListFrame(LabelFrame):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.Gui_Show()
        self.columnconfigure(0,weight=1)
        self.columnconfigure(1,weight=0)
        self.rowconfigure(0,weight=1)
    def Gui_Show(self):
        scbar=tk.Scrollbar(self)
        self.lb=tk.Listbox(self,selectmode="SINGLE",yscrollcommand=scbar.set)
        scbar.config(command=self.lb.yview)
        self.lb.grid(column=0,row=0,sticky="NSWE")
        scbar.grid(column=1,row=0,sticky="NS")
        self.lb.bind('<<ListboxSelect>>',self.Gui_BindDeal)
    def Gui_BindDeal(self,e):
        if self.lb.curselection()==():
            return
        print("index{}".format(self.lb.curselection()))
        print("Click{}".format(self.lb.get(self.lb.curselection())))
        self.m_CallBackFunc(self.lb.curselection()[0],self.lb.get(self.lb.curselection()))
        
    def m_ListDataToGui(self,listData:list):
        self.lb.delete(0,'end')
        for idx in listData:
            self.lb.insert('end',idx)
    def m_CallBackFunc(self,a,b):
        '''
        index|select
        '''
        print("{}-{}".format(a,b))
    def m_Update_Item(self,label_list:list):
        self.lb.delete(0,'end')
        for idx in label_list:
            self.lb.insert('end',"[{}] | {}".format(label_list.index(idx),idx))
    def m_Item_Select(self,num):
        self.lb.selection_clear(0,'end')
        self.lb.activate(num)
        self.lb.selection_set(num)
        self.lb.see(num)



import tkinter as tk
class ToolTip(object):
    def __init__(self, widget):
        self.widget = widget
        self.tipwindow = None
        self.id = None
        self._wraplength=300
        self.x = self.y = 0
    def showtip(self, text):
        "Display text in tooltip window"
        self.text = text
        if self.tipwindow or not self.text:
            return
        x, y, _cx, cy = self.widget.bbox("insert")
        x = x + self.widget.winfo_rootx() + 27
        y = y + cy + self.widget.winfo_rooty() +27
        self.tipwindow = tw = tk.Toplevel(self.widget)
        tw.wm_overrideredirect(1)
        tw.wm_geometry("+%d+%d" % (x, y))
        label = tk.Label(tw, text=self.text,wraplength=self._wraplength, justify=tk.LEFT,
        background="#ffffe0", relief=tk.SOLID, borderwidth=1,
        font=("微软雅黑", "12", "normal"))
        label.pack(ipadx=1)
    def hidetip(self):
        tw = self.tipwindow
        self.tipwindow = None
        if tw:
            tw.destroy()
    def setwordlenth(self,wraplen:int=300):
        self._wraplength = wraplen
 
#===========================================================
def TipShow( widget, text,wordlenth:int=300):
    '''
    arg1 控件对象
    arg2 提示信息
    '''
    toolTip = ToolTip(widget)
    toolTip.setwordlenth(wordlenth)
    def enter(event):
        toolTip.showtip(text)
    def leave(event):
        toolTip.hidetip()
    widget.bind('<Enter>', enter)
    widget.bind('<Leave>', leave)

# if __name__=="__main__":
#     win = tk.Tk()
#     ll = tk.Label(win,text="2333")
#     ll.grid(column=0,row=0)
#     TipShow(ll,"2122233")

#     win.mainloop()



import tkinter as tk

import tktkrs #rust for tktk,tktk的性能优化库
class TableFrame(tk.LabelFrame):
    def __init__(self,*args,heads=[str(idx) for idx in range(10)],weights:list=[1 for idx in range(10)],body_row=20,**Kwards):
        '''args: heads:list,weights:list[int],body_row:int;
            例:heads=["姓名","年龄","性别"],weights=[1,1,1],body_row=20;

            其中 heads设置表头信息,weights设置每列占比,body_row设置显示行数
        '''
        super().__init__(*args,**Kwards)
        self.database = tktkrs.Database()
        self.page = tk.IntVar()
        self.pages = 0
        self._inner_args=[heads,weights,body_row]
        self._design()
        self._event()
    def _design(self):
        self.table=OnlyTable(self,heads=self._inner_args[0],weights=self._inner_args[1],body_row=self._inner_args[2])
        self.table.grid(column=0,row=0,sticky='wnse')
        self.scale=tk.Scale(self,variable=self.page,from_=0,to=0,command=self._scale_update)
        self.scale.grid(column=1,row=0,sticky='ns')
        self.columnconfigure(0,weight=1)
        self.rowconfigure(0,weight=1)
    def _event(self):
        self.scale.bind("<MouseWheel>", self._wheel)
    def _wheel(self,e):
        if e.delta<0:
            self.page.set(self.page.get()+1)
        else:
            self.page.set(self.page.get()-1)
        self._scale_update(2)
    def _scale_update(self,e):
        self.get_show_data = self.database.get_show_data(self.page.get(),self._inner_args[2])
        self.table.update_data(self.get_show_data)
    def clear_data(self):
        self.database=tktkrs.Database()
        self.pages = self.database.get_len()/self._inner_args[2]
        self.scale.configure(to=self.pages)
        self._scale_update(2)
    def insert_data(self,data,update:bool=True):
        self.database.insert_data(data)
        if update:
            self.pages = self.database.get_len()/self._inner_args[2]
            self.scale.configure(to=self.pages)
            self._scale_update(2)
    def get_all_database(self):
        return self.database.get_all()
        


class OnlyTable(tk.LabelFrame):
    def __init__(self,*args,heads=[str(idx) for idx in range(10)],weights:list=[1 for idx in range(10)],body_row=10,**Kwards):
        super().__init__(*args,**Kwards)
        self.heads = heads
        self.weights = weights
        self.body_row = body_row
        self._design()
        self._clear_items()
    def _design(self):
        [tk.Label(self,text=idx[1],relief="solid").grid(column=idx[0],row=0,sticky='wnse') for idx in enumerate(self.heads)]
        self.items = [[] for _ in range(self.body_row)]
        col = len(self.heads)
        self.items = [[tk.Label(self,text="233",width=20) for _ in range(col)] for _ in range(self.body_row)]
        [[idy[1].grid(column=idy[0],row=idx[0]+1,sticky='wnse') for idy in enumerate(idx[1])] for idx in enumerate(self.items)]
        [self.columnconfigure(idx[0],weight=idx[1]) for idx in enumerate(self.weights)]
        [self.rowconfigure(idx,weight=1) for idx in range(self.body_row+1)]
    def _clear_items(self):
        [[[idy.configure(bg="white"),idy.configure(text="")] for idy in idx] for idx in self.items]
    def update_data(self,data_list:list):
        self._clear_items()
        [[[self.items[idx[0]][idy[0]].configure(text=idy[1][0]),self.items[idx[0]][idy[0]].configure(bg=idy[1][1])] if len(idy[1])==2 else self.items[idx[0]][idy[0]].configure(text=idy[1][0]) for idy in enumerate(idx[1])] for idx in enumerate(data_list)]

if __name__=="__main__":

    win = tk.Tk()
    win.geometry("600x300")
    tk.Label().configure
    tab=TableFrame(win,text="22",heads=[str(idx) for idx in range(10)],weights=[1 for idx in range(10)],body_row=10)
    tab.grid(column=0,row=0,sticky="wnse")
    win.columnconfigure(0,weight=1)
    win.rowconfigure(0,weight=1)
    [tab.insert_data([[str(idx)*idx*idy,"red"] if idx%2 else [str(idx)] for  idy  in range(10)]) for idx  in range(11)]
    # tab.clear_data()
    win.mainloop()



from setuptools import setup,find_packages

with open("README.md","r",encoding="utf-8") as fh:
    long_description = fh.read()

setup(name='tktk',
      version='0.4.1',
      description='tkinter的增强控件,将tkinter的基础控件进行封装,给予更强大的控件功能,所有控件继承于LabelFrame进行封装,使用方法和普通控件没什么区别;',
      long_description=long_description,
      long_description_content_type='text/markdown',
      classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
      url='https://gitee.com/w-8/tktk',
      author='bili:凿寂',
      author_email='mdzzdyxc@163.com',
      license='MIT',
      packages=find_packages(),
      zip_safe=True
     )
#python3 setup.py sdist bdist_wheel
#python3 -m twine upload dist/*


from tkinter import Button
import tkinter as tk

from PIL import ImageSequence,Image


class RollingLabel(Button):
    def __init__(self,*argv,gif_path:str,**kwords):

        super().__init__(*argv,**kwords)
        im = Image.open(gif_path)
        imm = tk.PhotoImage(gif_path)
        print(list(gif_path))
        print(imm)
        # self.iter = list(ImageSequence.Iterator(im))
        self.frames = [tk.PhotoImage(file=gif_path, format='gif -index %i' %(i)) for i in range(26)]
        self.run()
    def run(self):
        self.frames.append(self.frames.pop(0))
        self["image"] =  self.frames[0]#self.iter.__sizeof__()
        self.after(100,self.run)

if __name__=="__main__":
    win = tk.Tk()
    xe = RollingLabel(win,gif_path=r"D:\coded\filestore\ww.gif")
    xe.grid(column=0,row=0,sticky="WNSE")
    win.columnconfigure(0,weight=1)
    win.rowconfigure(0,weight=1)
    win.mainloop()